SystemOrganization addCategory: #'Naiad-Platforms'!
SystemOrganization addCategory: #'Naiad-Modules-Actions'!

ProtoObject subclass: #MemoryControl
	instanceVariableNames: ''
	classVariableNames: 'MemoryNames MemoryOperations'
	poolDictionaries: ''
	category: 'Naiad-Modules-Actions'!

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 9/7/2012 20:49'!
connectedMemoryNames
	^(RemoteMessagingServer activeServer activeClients collect: [:client | client stream port]) collect: [:port | self nameOfMemoryAtPort: port]! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 8/29/2012 23:26'!
disconnectedMemoryNames
	^self memoryNames copyWithoutAll: self connectedMemoryNames! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 8/28/2012 23:52'!
idOfMemoryNamed: memoryName
	^MemoryNames keyAtValue: memoryName! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 10/19/2012 02:51'!
initialize
	MemoryNames := Dictionary new.
	MemoryOperations := (
		(Dictionary new)
			at: 'resume'
			put: [:memoryControl :memoryID | memoryControl resume: memoryID];
			at: 'suspend'
			put: [:memoryControl :memoryID | memoryControl suspend: memoryID];
			yourself)! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 8/28/2012 23:48'!
memoryNames
	^MemoryNames values! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 9/11/2012 22:05'!
nameOfMemoryAtPort: port
	MemoryNames keysDo: [:id |id asIPPort = port ifTrue: [^MemoryNames at: id]].
	^'(unknown)'! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 10/20/2012 14:06'!
nameOfMemoryWithID: aUUID
	^MemoryNames at: aUUID! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 8/28/2012 23:44'!
setNameOfMemoryWithID: aUUID to: memoryName
	MemoryNames at: aUUID put: memoryName! !

!MemoryControl class methodsFor: 'as yet unclassified' stamp: 'crl 10/20/2012 14:13'!
summaryOfPeer: remoteRemoteMessagingClient
	| memoryID |

	memoryID := remoteRemoteMessagingClient memoryID.

	^((String new: 32) writableStream)
		nextPutAll: 'memory ''';
		nextPutAll: (self nameOfMemoryWithID: memoryID);
		nextPutAll: ''' at ';
		nextPutAll: remoteRemoteMessagingClient peerAddress hostname;
		contents! !

!MemoryControl methodsFor: 'as yet unclassified' stamp: 'crl 10/19/2012 02:51'!
generate
	| requestStream memoryID |

	requestStream := request resource stream.
	memoryID := self class idOfMemoryNamed: (HTTPServer decode: (requestStream throughAll: 'memories/'; upTo: $/)).
	(MemoryOperations at: (requestStream upToEnd)) value: self value: memoryID! !

!MemoryControl methodsFor: 'as yet unclassified' stamp: 'crl 8/30/2012 00:53'!
redirect
	self
		nextPutAll: '<html><head><title>redirecting...</title><body><meta http-equiv="refresh" content="0;url=';
		nextPutAll: (request at: 'Referer') only;
		nextPutAll: '"></body></html>'! !

!MemoryControl methodsFor: 'as yet unclassified' stamp: 'crl 10/16/2012 01:14'!
resume: memoryID
	HostPlatform resumeMemoryWithID: memoryID.
	(Delay forSeconds: 3) wait.
	(RemoteMessagingServer activeServer)
		connectToPort: memoryID asIPPort
		atHostNamed: 'localhost'.
	((RemoteMessagingServer peerInMemoryWithID: memoryID) classWithBaseID: EditHistory baseID) local: EditHistory local.

	self redirect! !

!MemoryControl methodsFor: 'as yet unclassified' stamp: 'crl 8/29/2012 01:16'!
storeOnNetStream: aNetStream
	aNetStream nextPutAll: self contents! !

!MemoryControl methodsFor: 'as yet unclassified' stamp: 'crl 9/7/2012 21:04'!
suspend: memoryID
	RemoteMessagingServer suspendMemoryWithID: memoryID.
	self redirect! !

Object subclass: #HostPlatform
	instanceVariableNames: ''
	classVariableNames: 'Current Platforms'
	poolDictionaries: ''
	category: 'Naiad-Platforms'!

!HostPlatform class methodsFor: 'as yet unclassified' stamp: 'crl 6/12/2001 18:15'!
current
	"Answer the current host platform."

	^Current! !

!HostPlatform class methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 01:57'!
initialize
	"Initialize myself."
	"I don't recall exactly what the platform system attributes are on the non-win32 platforms."

	Platforms := (
		(Dictionary new)
			at: 'Win32' put: Win32;
			at: 'Mac OS' put: Macintosh;
			at: 'Unix' put: Unix;
			at: 'RiscOS' put: RiscOS;
			yourself).
			
	Smalltalk addToStartUpList: self! !

!HostPlatform class methodsFor: 'as yet unclassified' stamp: 'crl 8/16/2012 12:35'!
processorPath
	^self subclassResponsibility! !

!HostPlatform class methodsFor: 'as yet unclassified' stamp: 'crl 10/19/2012 13:49'!
resumeMemoryNamed: memoryName
	self resumeMemoryWithID: (MemoryControl idOfMemoryNamed: memoryName)! !

!HostPlatform class methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 03:20'!
resumeMemoryWithID: aUUID
	Current resumeMemoryWithID: aUUID! !

!HostPlatform class methodsFor: 'as yet unclassified' stamp: 'crl 7/30/2006 17:42'!
startUp
	"Note the current host platform."

	Current := (Platforms at: Interpreter platformName) new! !

!HostPlatform methodsFor: 'as yet unclassified' stamp: 'crl 6/12/2001 18:37'!
pathFor: aFilename
	"Answer the path for aFilename, using my separator conventions."

	| stream |

	stream := (String new: 16) writableStream.
	aFilename printPathOn: stream.
	^stream contents! !

!HostPlatform methodsFor: 'as yet unclassified' stamp: 'crl 8/17/2012 18:15'!
printOn: aStream
	aStream
		nextPutAll: 'the ';
		print: self class;
		nextPutAll: ' platform'! !

!HostPlatform methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 10:28'!
processorName
	^self pathFor: (Filename appFolder childNamed: self processorNameTail)! !

!HostPlatform methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 01:58'!
processorNameTail
	^self subclassResponsibility! !

!HostPlatform methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 01:41'!
resumeMemoryWithID: aUUID
	Interpreter
		resumeMemoryNamed: (self pathFor: (Filename memoryFolder childNamed: aUUID printString))
		usingProcessorNamed: self processorName! !

!HostPlatform methodsFor: 'as yet unclassified' stamp: 'crl 6/12/2001 18:45'!
separator
	"Answer my filename segment separator."

	^self subclassResponsibility! !

HostPlatform subclass: #Macintosh
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Naiad-Platforms'!

!Macintosh class methodsFor: 'as yet unclassified' stamp: 'crl 8/16/2012 12:36'!
processorPath
	^Filename memoryFolder parent childNamed: 'MacOS/Spoon VM Opt'! !

!Macintosh methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 10:29'!
processorNameTail
	^'MacOS/Spoon VM Opt'! !

HostPlatform subclass: #Unix
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Naiad-Platforms'!

HostPlatform subclass: #Win32
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Naiad-Platforms'!

!Win32 class methodsFor: 'as yet unclassified' stamp: 'crl 8/16/2012 12:38'!
processorPath
	^Filename memoryFolder parent childNamed: 'win32/spoon.exe'! !

!Win32 methodsFor: 'as yet unclassified' stamp: 'crl 8/18/2012 18:27'!
pathFor: aFilename
	"Answer the path for aFilename, using my separator conventions."

	| stream |
	
	stream := (String new: 32) writableStream.
	
	^stream
		nextPut: $";
		nextPutAll: (
			((super pathFor: aFilename) copyFrom: 2)
				copyReplaceAll: '/'
				with:'\');
		nextPut: $";
		contents! !

!Win32 methodsFor: 'as yet unclassified' stamp: 'crl 8/24/2012 10:29'!
processorNameTail
	^'win32/spoon.exe'! !

!Win32 methodsFor: 'as yet unclassified' stamp: 'crl 6/12/2001 18:45'!
separator
	"Answer my filename segment separator."

	^$\! !
HostPlatform initialize!
MemoryControl initialize!
